<p align="right">
<a href="https://autorelease.general.dmz.palantir.tech/palantir/conjure-python-client"><img src="https://img.shields.io/badge/Perform%20an-Autorelease-success.svg" alt="Autorelease"></a>
</p>

# conjure-python-client

## Local development

A light-weight HTTP client library.

### Overview

conjure-python-client leverages [requests](http://docs.python-requests.org/en/master/) to provide a simple interface for making HTTP requests. conjure-python-client was designed to handle the RPC layer for clients generated by [conjure-python](https://github.com/palantir/conjure-python).

## Contributing

See the [CONTRIBUTING.md](./CONTRIBUTING.md) document.  Releases are published to [pypi](https://pypi.org/project/conjure-python-client/) on tag builds and are automatically re-published to [conda](https://anaconda.org/conda-forge/conjure-python-client) using [conda-forge](https://github.com/conda-forge/conjure-python-client-feedstock/).

## License
This project is made available under the [Apache 2.0 License](/LICENSE).
